;; Generated package description from repology.el  -*- no-byte-compile: t -*-
(define-package "repology" "1.2.3.0.20220320.111223" "Repology API access via Elisp" '((emacs "26.1")) :commit "b5829003decbdbe9002e7e1d29f45989a4659927" :url "https://elpa.gnu.org/packages/repology.html" :authors '(("Nicolas Goaziou" . "mail@nicolasgoaziou.fr")) :maintainer '("Nicolas Goaziou" . "mail@nicolasgoaziou.fr") :keywords '("web"))
